<?php
namespace MASCOTCOREINSOLAN\CPT\ShortcodeTemplates;

use MASCOTCOREINSOLAN\Lib;

/**
 * Singleton class
 * class CPT_ShortcodeTemplates
 * @package MASCOTCOREINSOLAN\CPT\ShortcodeTemplates;
 */
final class CPT_ShortcodeTemplates implements Lib\Mascot_Core_Insolan_Interface_PostType {
	
	/**
	 * @var string
	 */
	public 	$ptKey;
	public 	$ptKeyRewriteBase;
	public  $ptTaxKey;
	public  $ptTaxKeyRewriteBase;
	private $ptMenuIcon;
	private $ptSingularName;
	private $ptPluralName;

	/**
	 * Call this method to get singleton
	 *
	 * @return CPT_ShortcodeTemplates
	 */
	public static function Instance() {
		static $inst = null;
		if ($inst === null) {
			$inst = new CPT_ShortcodeTemplates();
		}
		return $inst;
	}
	
	/**
	 * Private ctor so nobody else can instance it
	 *
	 */
	private function __construct() {
		$this->ptSingularName = esc_html__( 'Shortcode Template', 'mascot-core-insolan-wp' );
		$this->ptPluralName = esc_html__( 'Shortcode Templates', 'mascot-core-insolan-wp' );
		$this->ptKey = 'shortcode-templates';
		$this->ptKeyRewriteBase = $this->ptKey;
		$this->ptMenuIcon = 'dashicons-mascot';
		add_filter( 'manage_edit-'.$this->ptKey.'_columns', array($this, 'customColumnsSettings') ) ;
		add_filter( 'manage_'.$this->ptKey.'_posts_custom_column', array($this, 'customColumnsContent') ) ;
		add_filter( 'rwmb_meta_boxes', array($this, 'regMetaBoxes') ) ;
	}

	/**
	 * @return string
	 */
	public function getPTKey() {
		return $this->ptKey;
	}

	/**
	 * @return string
	 */
	public function getPTTaxKey() {
		return $this->ptTaxKey;
	}

	/**
	 * registers custom post type & Tax
	 */
	public function register() {
		$this->registerCustomPostType();
	}
	
	/**
	 * Regsiters custom post type
	 */
	private function registerCustomPostType() {


		$labels = array(
			'name'					=> $this->ptPluralName,
			'singular_name'			=> $this->ptPluralName . ' ' . esc_html__( 'Item', 'mascot-core-insolan-wp' ),
			'menu_name'				=> $this->ptPluralName,
			'name_admin_bar'		=> $this->ptPluralName,
			'archives'				=> esc_html__( 'Item Archives', 'mascot-core-insolan-wp' ),
			'attributes'			=> esc_html__( 'Item Attributes', 'mascot-core-insolan-wp' ),
			'parent_item_colon'		=> esc_html__( 'Parent Item:', 'mascot-core-insolan-wp' ),
			'all_items'				=> esc_html__( 'All Items', 'mascot-core-insolan-wp' ),
			'add_new_item'			=> esc_html__( 'Add New Item', 'mascot-core-insolan-wp' ),
			'add_new'				=> esc_html__( 'Add New', 'mascot-core-insolan-wp' ),
			'new_item'				=> esc_html__( 'New Item', 'mascot-core-insolan-wp' ),
			'edit_item'				=> esc_html__( 'Edit Item', 'mascot-core-insolan-wp' ),
			'update_item'			=> esc_html__( 'Update Item', 'mascot-core-insolan-wp' ),
			'view_item'				=> esc_html__( 'View Item', 'mascot-core-insolan-wp' ),
			'view_items'			=> esc_html__( 'View Items', 'mascot-core-insolan-wp' ),
			'search_items'			=> esc_html__( 'Search Item', 'mascot-core-insolan-wp' ),
			'not_found'				=> esc_html__( 'Not found', 'mascot-core-insolan-wp' ),
			'not_found_in_trash'	=> esc_html__( 'Not found in Trash', 'mascot-core-insolan-wp' ),
			'featured_image'		=> esc_html__( 'Featured Image', 'mascot-core-insolan-wp' ),
			'set_featured_image'	=> esc_html__( 'Set featured image', 'mascot-core-insolan-wp' ),
			'remove_featured_image'	=> esc_html__( 'Remove featured image', 'mascot-core-insolan-wp' ),
			'use_featured_image'	=> esc_html__( 'Use as featured image', 'mascot-core-insolan-wp' ),
			'insert_into_item'		=> esc_html__( 'Insert into item', 'mascot-core-insolan-wp' ),
			'uploaded_to_this_item'	=> esc_html__( 'Uploaded to this item', 'mascot-core-insolan-wp' ),
			'items_list'			=> esc_html__( 'Items list', 'mascot-core-insolan-wp' ),
			'items_list_navigation'	=> esc_html__( 'Items list navigation', 'mascot-core-insolan-wp' ),
			'filter_items_list'		=> esc_html__( 'Filter items list', 'mascot-core-insolan-wp' ),
		);

		$args = array(
			'label'						=> $this->ptSingularName,
			'description'				=> esc_html__( 'Post Type Description', 'mascot-core-insolan-wp' ),
			'labels'					=> $labels,
			'supports'					=> array( 'title', 'editor' ),
			'hierarchical'				=> false,
			'public'					=> true,
			'show_ui'					=> true,
			'show_in_menu'				=> true,
			'menu_position'				=> 30,
			'menu_icon'					=> $this->ptMenuIcon,
			'show_in_admin_bar'			=> true,
			'show_in_nav_menus'			=> false,
			'can_export'				=> true,
			'has_archive'				=> false,
			'exclude_from_search'		=> true,
			'publicly_queryable'		=> true,
			'capability_type'			=> 'page',
            'rewrite'               	=> false,
		);
		register_post_type( $this->ptKey, $args );

	}
	
	/**
	 * Custom Columns Settings
	 */
	public function customColumnsSettings( $columns ) {

		$columns = array(
			'cb'				=> '<input type="checkbox" />',
			'title'			=> esc_html__( 'Title', 'mascot-core-insolan-wp' ),
			'shortcode'		=> esc_html__( 'Shortcode', 'mascot-core-insolan-wp' ),
			'date'			=> esc_html__( 'Date', 'mascot-core-insolan-wp' ),
		);
		return $columns;
	}

	/**
	 * Custom Columns Content
	 */
	public function customColumnsContent( $columns ) {
		global $post;
		switch( $columns ) {
			case 'shortcode' :
				echo '<input type=\'text\' class=\'widefat\' value=\'[tm_shortcode_templates id="'.$post->ID.'"]\' readonly="">';
			break;

			default :
			break;
		}
	}

	/**
	 * Registers Meta Boxes
	 */
	public function regMetaBoxes( $meta_boxes ) {
		if (empty($_GET['post'])) {
			return $meta_boxes;
		}
		$meta_boxes[] = array(
			'id'		 => 'shortcode_template_meta_box',
			'title'	  => esc_html__( 'Shortcode Meta Box', 'mascot-core-insolan-wp' ),
			'post_types' => $this->ptKey,
			'context'   => 'side',
			'priority'   => 'high',
			'fields'		=> array(
				array(
					'id'	=> 'tm_shortcode_template',
					'name'		=> esc_html__( 'Shortcode', 'mascot-core-insolan-wp' ),
					'type'	=> 'text',
					'readonly'	=> true,
					'std'	=> '[tm_shortcode_templates id="'.$_GET['post'].'"]',
				),
			),
		);
		return $meta_boxes;
	}

}